cocos.batch module — cocos v0.6.5 documentation

# cocos.batch module

Batch

## Batches

Batches allow you to optimize the number of gl calls using pyglets batch

class `BatchNode`

  Bases: `cocos.cocosnode.CocosNode`

  `add`(child, z=0, name=None)
  `draw`()
  `remove`(child)
  `visit`()

    All children are placed in to self.batch, so nothing to visit

class `BatchableNode`

  Bases: `cocos.cocosnode.CocosNode`

  `add`(child, z=0, name=None)
  `remove`(child)
  `set_batch`(batch, groups=None, z=0)